Struct ra_ap_rust_analyzer::config::RunnablesConfig [−][src]
pub struct RunnablesConfig {
pub override_cargo: Option<String>,
pub cargo_extra_args: Vec<String>,
}Expand description
Configuration for runnable items, such as main function or tests.
Fields
override_cargo: Option<String>Custom command to be executed instead of cargo for runnables.
cargo_extra_args: Vec<String>Additional arguments for the cargo, e.g. --release.